PyTorchRect class

Constructors

PyTorchRect(double left, double top, double width, double height, double right, double bottom)

Properties

bottom ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
left ↔ double
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double
getter/setter pair
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited