ResultObjectDetection class

Constructors

ResultObjectDetection(int classIndex, double score, PyTorchRect rect)

Properties

classIndex ↔ int
getter/setter pair
className ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rect ↔ PyTorchRect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited